IMTreatment.vortex\_criterions.FTLE.ftle module
===============================================

.. automodule:: IMTreatment.vortex_criterions.FTLE.ftle
    :members:
    :undoc-members:
    :show-inheritance:
